@@ -8,6 +8,7 @@ except ImportError:
     from importlib_metadata import metadata, version
     from importlib_resources import files
 
+from .console_script import sort_excel_file
 from .excel_definition import Exceldefinition
 from .excel_operation import (
     output_to_csv_file,
@@ -40,6 +41,7 @@ __all__ = [
     "StoryFactory",
     "sort_stories_by_property_and_order",
     "sort_stories_by_raise_ranking",
+    "sort_excel_file",
 ]
 
 del metadata
